@@ -8,6 +8,6 @@ from ..testing_utils import assert_no_logs
 
 
 @assert_no_logs
-@pytest.mark.parametrize('css', (HTML5_UA, HTML5_UA_FORM, HTML5_PH))
+@pytest.mark.parametrize('css', [HTML5_UA, HTML5_UA_FORM, HTML5_PH])
 def test_ua_stylesheets(css):
     CSS(string=css)
