@@ -74,98 +74,98 @@ def test_empty_property_value(prop):
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
-    ('1px, 3em, auto, auto', ((1, 'px'), (3, 'em'), 'auto', 'auto')),
-    ('1px, 3em, auto auto', ((1, 'px'), (3, 'em'), 'auto', 'auto')),
-    ('1px 3em auto 1px', ((1, 'px'), (3, 'em'), 'auto', (1, 'px'))),
-))
+@pytest.mark.parametrize(('rule', 'value'), [
+    ('1px, 3EM, auto, auto', ((1, 'px'), (3, 'em'), 'auto', 'auto')),
+    ('1px,3em,auto,1px', ((1, 'px'), (3, 'em'), 'auto', (1, 'px'))),
+])
 def test_clip(rule, value):
     assert get_value(f'clip: rect({rule})') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'clip: square(1px, 3em, auto, auto)',
+    'clip: rect(1px 3em auto auto)',
     'clip: rect(1px, 3em, auto)',
     'clip: rect(1px, 3em / auto)',
-))
+])
 def test_clip_invalid(rule):
     assert_invalid(rule)
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('counter-reset: foo bar 2 baz', (('foo', 0), ('bar', 2), ('baz', 0))),
     ('counter-increment: foo bar 2 baz', (('foo', 1), ('bar', 2), ('baz', 1))),
     ('counter-reset: foo', (('foo', 0),)),
     ('counter-set: FoO', (('FoO', 0),)),
     ('counter-increment: foo bAr 2 Bar', (('foo', 1), ('bAr', 2), ('Bar', 1))),
     ('counter-reset: none', ()),
-))
+])
 def test_counters(rule, value):
     assert get_value(rule) == value
 
 
-@pytest.mark.parametrize('rule, warning', (
+@pytest.mark.parametrize(('rule', 'warning'), [
     ('counter-reset: foo initial', 'Invalid counter name: initial.'),
     ('counter-reset: foo none', 'Invalid counter name: none.'),
-))
+])
 def test_counters_warning(rule, warning):
     assert_invalid(rule, warning)
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
-    'counter-reset: foo 3px',
+@pytest.mark.parametrize('rule', [
+    'counter-reset: foo 3pX',
     'counter-reset: 3',
-))
+])
 def test_counters_invalid(rule):
     assert_invalid(rule)
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('letter-spacing: normal', 'normal'),
     ('letter-spacing: 3px', (3, 'px')),
     ('word-spacing: normal', 'normal'),
     ('word-spacing: 3px', (3, 'px')),
-))
+])
 def test_spacing(rule, value):
     assert get_value(rule) == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'letter-spacing: 3',
     'word-spacing: 3',
-))
+])
 def test_spacing_invalid(rule):
     assert_invalid(rule)
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('none', 'none'),
     ('overline', {'overline'}),
     ('overline blink line-through', {'blink', 'line-through', 'overline'}),
-))
+])
 def test_text_decoration_line(rule, value):
     assert get_value(f'text-decoration-line: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('solid', 'solid'),
     ('double', 'double'),
     ('dotted', 'dotted'),
     ('dashed', 'dashed'),
-))
+])
 def test_text_decoration_style(rule, value):
     assert get_value(f'text-decoration-style: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('200px', ((200, 'px'), (200, 'px'))),
     ('200px 300pt', ((200, 'px'), (300, 'pt'))),
     ('auto', ((210, 'mm'), (297, 'mm'))),
@@ -175,55 +175,55 @@ def test_text_decoration_style(rule, value):
     ('A3 landscape', ((420, 'mm'), (297, 'mm'))),
     ('portrait A3', ((297, 'mm'), (420, 'mm'))),
     ('landscape A3', ((420, 'mm'), (297, 'mm'))),
-))
+])
 def test_size(rule, value):
     assert get_value(f'size: {rule}') == value
 
 
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'A3 landscape A3',
     'A12',
     'foo',
     'foo bar',
     '20%',
-))
+])
 def test_size_invalid(rule):
     assert_invalid(f'size: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('none', ()),
     ('translate(6px) rotate(90deg)', (
         ('translate', ((6, 'px'), (0, 'px'))), ('rotate', pi / 2))),
     ('translate(-4px, 0)', (('translate', ((-4, 'px'), (0, None))),)),
     ('translate(6px, 20%)', (('translate', ((6, 'px'), (20, '%'))),)),
     ('scale(2)', (('scale', (2, 2)),)),
-    ('translate(6px 20%)', (('translate', ((6, 'px'), (20, '%'))),)),
-))
+])
 def test_transform(rule, value):
     assert get_value(f'transform: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'lipsumize(6px)',
     'foo',
     'scale(2) foo',
     '6px',
-))
+    'translate(6px 20%)',
+])
 def test_transform_invalid(rule):
     assert_invalid(f'transform: {rule}')
 
 
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'inexistent-gradient(blue, green)',
-))
+])
 def test_background_image_invalid(rule):
     assert_invalid(f'background-image: {rule}')
 
 
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     # One token, vertical
     ('top', (('left', (50, '%'), 'top', (0, '%')),)),
     ('bottom', (('left', (50, '%'), 'top', (100, '%')),)),
@@ -250,7 +250,7 @@ def test_background_image_invalid(rule):
     ('right 10% bottom', (('right', (10, '%'), 'bottom', (0, '%')),)),
 
     # Four tokens
-    ('left 10% bottom 3px', (('left', (10, '%'), 'bottom', (3, 'px')),)),
+    ('left 10% bottom 3PX', (('left', (10, '%'), 'bottom', (3, 'px')),)),
     ('bottom 3px left 10%', (('left', (10, '%'), 'bottom', (3, 'px')),)),
     ('right 10% top 3px', (('right', (10, '%'), 'top', (3, 'px')),)),
     ('top 3px right 10%', (('right', (10, '%'), 'top', (3, 'px')),)),
@@ -269,58 +269,58 @@ def test_background_image_invalid(rule):
                 ('top', (0, '%')), ('center', (50, '%')), ('bottom', (100, '%')),
                 ('7%', (7, '%')), ('1.5px', (1.5, 'px')))
     ),
-))
+])
 def test_background_position(rule, value):
     assert get_value(f'background-position: {rule}') == value
 
 
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     '10px lipsum',
     'left center 3px',
     '3px left',
     'bottom 4%',
     'bottom top'
-))
+])
 def test_background_position_invalid(rule):
     assert_invalid(f'background-position: {rule}')
 
 
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     ('"My" Font, serif'),
     ('"My" "Font", serif'),
     ('"My", 12pt, serif'),
-))
+])
 def test_font_family_invalid(rule):
     assert_invalid(f'font-family: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('1px', (1, 'px')),
     ('1.1%', (1.1, '%')),
-    ('1em', (1, 'em')),
+    ('1Em', (1, 'em')),
     ('1', (1, None)),
     ('1.3', (1.3, None)),
     ('-0', (0, None)),
     ('0px', (0, 'px')),
-))
+])
 def test_line_height(rule, value):
     assert get_value(f'line-height: {rule}') == value
 
 
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     '1deg',
     '-1px',
     '-1',
     '-0.5%',
     '1px 1px',
-))
+])
 def test_line_height_invalid(rule):
     assert_invalid(f'line-height: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'symbols()',
     'symbols(cyclic)',
     'symbols(symbolic)',
@@ -329,13 +329,13 @@ def test_line_height_invalid(rule):
     'symbols(numeric "1")',
     'symbols(test "a" "b")',
     'symbols(fixed symbolic "a" "b")',
-))
+])
 def test_list_style_type_invalid(rule):
     assert_invalid(f'list-style-type: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('none', 'none'),
     ('from-image', 'from-image'),
     ('90deg', (pi / 2, False)),
@@ -344,13 +344,13 @@ def test_list_style_type_invalid(rule):
     ('0deg flip', (0, True)),
     ('flip 90deg', (pi / 2, True)),
     ('flip', (0, True)),
-))
+])
 def test_image_orientation(rule, value):
     assert get_value(f'image-orientation: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none none',
     'unknown',
     'none flip',
@@ -361,26 +361,26 @@ def test_image_orientation(rule, value):
     'flip flip',
     '90deg flop',
     '90deg 180deg',
-))
+])
 def test_image_orientation_invalid(rule):
     assert_invalid(f'image-orientation: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('1', ((1, None),)),
     ('1 2    3 4', ((1, None), (2, None), (3, None), (4, None))),
     ('50% 1000.1 0', ((50, '%'), (1000.1, None), (0, None))),
     ('1% 2% 3% 4%', ((1, '%'), (2, '%'), (3, '%'), (4, '%'))),
     ('fill 10% 20', ('fill', (10, '%'), (20, None))),
     ('0 1 0.5 fill', ((0, None), (1, None), (0.5, None), 'fill')),
-))
+])
 def test_border_image_slice(rule, value):
     assert get_value(f'border-image-slice: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     '1, 2',
     '-10',
@@ -389,13 +389,13 @@ def test_border_image_slice(rule, value):
     '-0.3',
     '1 fill 2',
     'fill 1 2 3 fill',
-))
+])
 def test_border_image_slice_invalid(rule):
     assert_invalid(f'border-image-slice: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('1', ((1, None),)),
     ('1 2    3 4', ((1, None), (2, None), (3, None), (4, None))),
     ('50% 1000.1 0', ((50, '%'), (1000.1, None), (0, None))),
@@ -404,13 +404,13 @@ def test_border_image_slice_invalid(rule):
     ('1 auto', ((1, None), 'auto')),
     ('auto auto', ('auto', 'auto')),
     ('auto auto auto 2', ('auto', 'auto', 'auto', (2, None))),
-))
+])
 def test_border_image_width(rule, value):
     assert get_value(f'border-image-width: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     '1, 2',
     '1 -2',
@@ -420,24 +420,24 @@ def test_border_image_width(rule, value):
     '-3px',
     'auto auto auto auto auto',
     '1 2 3 4 5',
-))
+])
 def test_border_image_width_invalid(rule):
     assert_invalid(f'border-image-width: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('1', ((1, None),)),
     ('1 2    3 4', ((1, None), (2, None), (3, None), (4, None))),
     ('50px 1000.1 0', ((50, 'px'), (1000.1, None), (0, None))),
     ('1in 2px 3em 4', ((1, 'in'), (2, 'px'), (3, 'em'), (4, None))),
-))
+])
 def test_border_image_outset(rule, value):
     assert get_value(f'border-image-outset: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'auto',
     '1, 2',
@@ -447,48 +447,48 @@ def test_border_image_outset(rule, value):
     '1px 2px 3px -10px',
     '-3px',
     '1 2 3 4 5',
-))
+])
 def test_border_image_outset_invalid(rule):
     assert_invalid(f'border-image-outset: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('stretch', ('stretch',)),
     ('repeat repeat', ('repeat', 'repeat')),
     ('round     space', ('round', 'space')),
-))
+])
 def test_border_image_repeat(rule, value):
     assert get_value(f'border-image-repeat: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'test',
     'round round round',
     'stretch space round',
     'repeat test',
-))
+])
 def test_border_image_repeat_invalid(rule):
     assert_invalid(f'border-image-repeat: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('1', ((1, None),)),
     ('1 2    3 4', ((1, None), (2, None), (3, None), (4, None))),
     ('50% 1000.1 0', ((50, '%'), (1000.1, None), (0, None))),
     ('1% 2% 3% 4%', ((1, '%'), (2, '%'), (3, '%'), (4, '%'))),
     ('fill 10% 20', ('fill', (10, '%'), (20, None))),
     ('0 1 0.5 fill', ((0, None), (1, None), (0.5, None), 'fill')),
-))
+])
 def test_mask_border_slice(rule, value):
     assert get_value(f'mask-border-slice: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     '1, 2',
     '-10',
@@ -497,13 +497,13 @@ def test_mask_border_slice(rule, value):
     '-0.3',
     '1 fill 2',
     'fill 1 2 3 fill',
-))
+])
 def test_mask_border_slice_invalid(rule):
     assert_invalid(f'mask-border-slice: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('1', ((1, None),)),
     ('1 2    3 4', ((1, None), (2, None), (3, None), (4, None))),
     ('50% 1000.1 0', ((50, '%'), (1000.1, None), (0, None))),
@@ -512,13 +512,13 @@ def test_mask_border_slice_invalid(rule):
     ('1 auto', ((1, None), 'auto')),
     ('auto auto', ('auto', 'auto')),
     ('auto auto auto 2', ('auto', 'auto', 'auto', (2, None))),
-))
+])
 def test_mask_border_width(rule, value):
     assert get_value(f'mask-border-width: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     '1, 2',
     '1 -2',
@@ -528,24 +528,24 @@ def test_mask_border_width(rule, value):
     '-3px',
     'auto auto auto auto auto',
     '1 2 3 4 5',
-))
+])
 def test_mask_border_width_invalid(rule):
     assert_invalid(f'mask-border-width: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('1', ((1, None),)),
     ('1 2    3 4', ((1, None), (2, None), (3, None), (4, None))),
     ('50px 1000.1 0', ((50, 'px'), (1000.1, None), (0, None))),
     ('1in 2px 3em 4', ((1, 'in'), (2, 'px'), (3, 'em'), (4, None))),
-))
+])
 def test_mask_border_outset(rule, value):
     assert get_value(f'mask-border-outset: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'auto',
     '1, 2',
@@ -555,56 +555,56 @@ def test_mask_border_outset(rule, value):
     '1px 2px 3px -10px',
     '-3px',
     '1 2 3 4 5',
-))
+])
 def test_mask_border_outset_invalid(rule):
     assert_invalid(f'mask-border-outset: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('stretch', ('stretch',)),
     ('repeat repeat', ('repeat', 'repeat')),
     ('round     space', ('round', 'space')),
-))
+])
 def test_mask_border_repeat(rule, value):
     assert get_value(f'mask-border-repeat: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'test',
     'round round round',
     'stretch space round',
     'repeat test',
-))
+])
 def test_mask_border_repeat_invalid(rule):
     assert_invalid(f'mask-border-repeat: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('alpha', 'alpha'),
     ('luminance', 'luminance'),
     ('alpha     ', 'alpha'),
-))
+])
 def test_mask_border_mode(rule, value):
     assert get_value(f'mask-border-mode: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'test',
     'alpha alpha',
     'alpha luminance',
-))
+])
 def test_mask_border_mode_invalid(rule):
     assert_invalid(f'mask-border-mode: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('test content(text)', (('test', (('content()', 'text'),)),)),
     ('test content(before)', (('test', (('content()', 'before'),)),)),
     ('test "string"', (('test', (('string', 'string'),)),)),
@@ -626,44 +626,43 @@ def test_mask_border_mode_invalid(rule):
             ('attr()', ('title', 'string', '')),
             ('attr()', ('title', 'string', '')),
             ('counter()', ('count', 'decimal')))),)),
-))
+])
 def test_string_set(rule, value):
     assert get_value(f'string-set: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'test',
     'test test1',
     'test content(test)',
     'test unknown()',
-    'test attr(id, class)',
-))
+])
 def test_string_set_invalid(rule):
     assert_invalid(f'string-set: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('normal', 'normal'),
     ('break-word', 'break-word'),
     ('inherit', 'inherit'),
-))
+])
 def test_overflow_wrap(rule, value):
     assert get_value(f'overflow-wrap: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'normal, break-word',
-))
+])
 def test_overflow_wrap_invalid(rule):
     assert_invalid(f'overflow-wrap: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('blue', ()),
     ('red', (None, ((1, 0, 0, 1),))),
     ('blue 1%, lime,red 2em ', (
@@ -694,7 +693,7 @@ def test_overflow_wrap_invalid(rule):
     ('to left bottom, blue', (('corner', 'bottom_left'),)),
     ('to bottom right, blue', (('corner', 'bottom_right'),)),
     ('to right bottom, blue', (('corner', 'bottom_right'),)),
-))
+])
 def test_linear_gradient(rule, value):
     direction = get_default_value(value, 0, ('angle', pi))
     colors = get_default_value(value, 1, ((0, 0, 1, 1),))
@@ -715,7 +714,7 @@ def test_linear_gradient(rule, value):
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     ' ',
     '1% blue',
     'blue 10deg',
@@ -732,14 +731,14 @@ def test_linear_gradient(rule, value):
     'top, blue',
     'to bottom up, blue',
     'bottom left, blue',
-))
+])
 def test_linear_gradient_invalid(rule):
     assert_invalid(f'background-image: linear-gradient({rule})')
     assert_invalid(f'background-image: repeating-linear-gradient({rule})')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('blue', ()),
     ('red', (None, None, None, ((1, 0, 0, 1),))),
     ('blue 1%, lime,red 2em ', (
@@ -762,8 +761,6 @@ def test_linear_gradient_invalid(rule):
         None, ('explicit', ((10, 'px'), (50, 'px'))))),
     ('ellipse 10px 50px, blue', (
         None, ('explicit', ((10, 'px'), (50, 'px'))))),
-    ('10px 50px, blue', (
-        None, ('explicit', ((10, 'px'), (50, 'px'))))),
     ('at top 10% right, blue', (
         None, None, ('right', (0, '%'), 'top', (10, '%')))),
     ('circle at bottom, blue', (
@@ -773,7 +770,7 @@ def test_linear_gradient_invalid(rule):
     ('closest-side circle at right 5em, blue', (
         'circle', ('keyword', 'closest-side'),
         ('left', (100, '%'), 'top', (5, 'em')))),
-))
+])
 def test_radial_gradient(rule, value):
     shape = get_default_value(value, 0, 'ellipse')
     size = get_default_value(value, 1, ('keyword', 'farthest-corner'))
@@ -795,7 +792,7 @@ def test_radial_gradient(rule, value):
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     ' ',
     '1% blue',
     'blue 10deg',
@@ -814,14 +811,14 @@ def test_radial_gradient(rule, value):
     '10% circle, blue',
     'circle 10%, blue',
     'at appex, blue',
-))
+])
 def test_radial_gradient_invalid(rule):
     assert_invalid(f'background-image: radial-gradient({rule})')
     assert_invalid(f'background-image: repeating-radial-gradient({rule})')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('40px', ((40, 'px'),)),
     ('2fr', ((2, 'fr'),)),
     ('18%', ((18, '%'),)),
@@ -833,14 +830,14 @@ def test_radial_gradient_invalid(rule):
     ('minmax(min-content, max-content)',
      (('minmax()', 'min-content', 'max-content'),)),
     ('min-content max-content', ('min-content', 'max-content')),
-))
+])
 def test_grid_auto_columns_rows(rule, value):
     assert get_value(f'grid-auto-columns: {rule}') == value
     assert get_value(f'grid-auto-rows: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     '40',
     'coucou',
     'fit-content',
@@ -850,14 +847,14 @@ def test_grid_auto_columns_rows(rule, value):
     '1fr 1fr coucou',
     'fit-content()',
     'fit-content(2%, 18%)',
-))
+])
 def test_grid_auto_columns_rows_invalid(rule):
     assert_invalid(f'grid-auto-columns: {rule}')
     assert_invalid(f'grid-auto-rows: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('row', ('row',)),
     ('column', ('column',)),
     ('row dense', ('row', 'dense')),
@@ -865,13 +862,13 @@ def test_grid_auto_columns_rows_invalid(rule):
     ('dense row', ('dense', 'row')),
     ('dense column', ('dense', 'column')),
     ('dense', ('dense', 'row')),
-))
+])
 def test_grid_auto_flow(rule, value):
     assert get_value(f'grid-auto-flow: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'row row',
     'column column',
     'dense dense',
@@ -883,13 +880,13 @@ def test_grid_auto_flow(rule, value):
     'coucou row',
     'coucou column',
     'row column dense',
-))
+])
 def test_grid_auto_flow_invalid(rule):
     assert_invalid(f'grid-auto-flow: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('none', 'none'),
     ('subgrid', ('subgrid', ())),
     ('subgrid [a] repeat(auto-fill, [b]) [c]',
@@ -911,14 +908,14 @@ def test_grid_auto_flow_invalid(rule):
      (('a',), 'auto', ('b',), ('minmax()', 'min-content', (1, 'fr')),
       ('b', 'c', 'd'), ('repeat()', 2, (('e',), (40, 'px'), ())),
       (), ('repeat()', 5, ((), 'auto', ())), ())),
-))
+])
 def test_grid_template_columns_rows(rule, value):
     assert get_value(f'grid-template-columns: {rule}') == value
     assert get_value(f'grid-template-rows: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'coucou',
     'subgrid subgrid',
     'subgrid coucou',
@@ -926,14 +923,14 @@ def test_grid_template_columns_rows(rule, value):
     'subgrid [coucou] repeat(auto-fit [wow])',
     'fit-content(18%) repeat(auto-fill, 15em)',
     '[coucou] [wow]',
-))
+])
 def test_grid_template_columns_rows_invalid(rule):
     assert_invalid(f'grid-template-columns: {rule}')
     assert_invalid(f'grid-template-rows: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('none', 'none'),
     ('"head head" "nav main" "foot ...."',
      (('head', 'head'), ('nav', 'main'), ('foot', None))),
@@ -943,25 +940,25 @@ def test_grid_template_columns_rows_invalid(rule):
      ((None, 'a'), ('b', 'a'), (None, 'a'))),
     ('"a b b" "c b b" "d e f"',
      (('a', 'b', 'b'), ('c', 'b', 'b'), ('d', 'e', 'f'))),
-))
+])
 def test_grid_template_areas(rule, value):
     assert get_value(f'grid-template-areas: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     '"head head coucou" "nav main" "foot ...."',
     '". a" "b c" ". a"',
     '". a" "b a" "a a"',
     '"a a a a" "a b b a" "a a a a"',
     '" "',
-))
+])
 def test_grid_template_areas_invalid(rule):
     assert_invalid(f'grid-template-areas: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('auto', 'auto'),
     ('4', (None, 4, None)),
     ('C', (None, None, 'C')),
@@ -971,7 +968,7 @@ def test_grid_template_areas_invalid(rule):
     ('span 4 c', ('span', 4, 'c')),
     ('4 span C', ('span', 4, 'C')),
     ('super 4 span', ('span', 4, 'super')),
-))
+])
 def test_grid_line(rule, value):
     assert get_value(f'grid-row-start: {rule}') == value
     assert get_value(f'grid-row-end: {rule}') == value
@@ -980,7 +977,7 @@ def test_grid_line(rule, value):
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'span',
     '0',
     '1.1',
@@ -991,7 +988,7 @@ def test_grid_line(rule, value):
     'auto auto',
     '-4 cOL span',
     'span 1.1 col',
-))
+])
 def test_grid_line_invalid(rule):
     assert_invalid(f'grid-row-start: {rule}')
     assert_invalid(f'grid-row-end: {rule}')
@@ -1000,7 +997,7 @@ def test_grid_line_invalid(rule):
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('normal', ('normal',)),
     ('baseline', ('first', 'baseline')),
     ('first baseline', ('first', 'baseline')),
@@ -1020,13 +1017,13 @@ def test_grid_line_invalid(rule):
     ('safe end', ('safe', 'end')),
     ('safe flex-start', ('safe', 'flex-start')),
     ('unsafe flex-start', ('unsafe', 'flex-start')),
-))
+])
 def test_align_content(rule, value):
     assert get_value(f'align-content: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'auto',
     'none',
     'auto auto',
@@ -1037,13 +1034,13 @@ def test_align_content(rule, value):
     'safe unsafe',
     'left',
     'right',
-))
+])
 def test_align_content_invalid(rule):
     assert_invalid(f'align-content: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('normal', ('normal',)),
     ('stretch', ('stretch',)),
     ('baseline', ('first', 'baseline')),
@@ -1064,13 +1061,13 @@ def test_align_content_invalid(rule):
     ('safe self-end', ('safe', 'self-end')),
     ('safe flex-start', ('safe', 'flex-start')),
     ('unsafe flex-start', ('unsafe', 'flex-start')),
-))
+])
 def test_align_items(rule, value):
     assert get_value(f'align-items: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'auto',
     'none',
     'auto auto',
@@ -1082,13 +1079,13 @@ def test_align_items(rule, value):
     'left',
     'right',
     'space-between',
-))
+])
 def test_align_items_invalid(rule):
     assert_invalid(f'align-items: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('auto', ('auto',)),
     ('normal', ('normal',)),
     ('stretch', ('stretch',)),
@@ -1110,13 +1107,13 @@ def test_align_items_invalid(rule):
     ('safe self-end', ('safe', 'self-end')),
     ('safe flex-start', ('safe', 'flex-start')),
     ('unsafe flex-start', ('unsafe', 'flex-start')),
-))
+])
 def test_align_self(rule, value):
     assert get_value(f'align-self: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'auto auto',
     'first last',
@@ -1127,13 +1124,13 @@ def test_align_self(rule, value):
     'left',
     'right',
     'space-between',
-))
+])
 def test_align_self_invalid(rule):
     assert_invalid(f'align-self: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('normal', ('normal',)),
     ('space-between', ('space-between',)),
     ('space-around', ('space-around',)),
@@ -1153,13 +1150,13 @@ def test_align_self_invalid(rule):
     ('safe right', ('safe', 'right')),
     ('safe flex-start', ('safe', 'flex-start')),
     ('unsafe flex-start', ('unsafe', 'flex-start')),
-))
+])
 def test_justify_content(rule, value):
     assert get_value(f'justify-content: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'auto',
     'none',
     'baseline',
@@ -1169,13 +1166,13 @@ def test_justify_content(rule, value):
     'start safe',
     'start end',
     'safe unsafe',
-))
+])
 def test_justify_content_invalid(rule):
     assert_invalid(f'justify-content: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('normal', ('normal',)),
     ('stretch', ('stretch',)),
     ('baseline', ('first', 'baseline')),
@@ -1202,13 +1199,13 @@ def test_justify_content_invalid(rule):
     ('legacy left', ('legacy', 'left')),
     ('left legacy', ('left', 'legacy')),
     ('legacy center', ('legacy', 'center')),
-))
+])
 def test_justify_items(rule, value):
     assert get_value(f'justify-items: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'auto',
     'none',
     'auto auto',
@@ -1218,13 +1215,13 @@ def test_justify_items(rule, value):
     'start end',
     'safe unsafe',
     'space-between',
-))
+])
 def test_justify_items_invalid(rule):
     assert_invalid(f'justify-items: {rule}')
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule, value', (
+@pytest.mark.parametrize(('rule', 'value'), [
     ('auto', ('auto',)),
     ('normal', ('normal',)),
     ('stretch', ('stretch',)),
@@ -1250,13 +1247,13 @@ def test_justify_items_invalid(rule):
     ('safe self-end', ('safe', 'self-end')),
     ('safe flex-start', ('safe', 'flex-start')),
     ('unsafe flex-start', ('unsafe', 'flex-start')),
-))
+])
 def test_justify_self(rule, value):
     assert get_value(f'justify-self: {rule}') == value
 
 
 @assert_no_logs
-@pytest.mark.parametrize('rule', (
+@pytest.mark.parametrize('rule', [
     'none',
     'auto auto',
     'first last',
@@ -1265,6 +1262,36 @@ def test_justify_self(rule, value):
     'start end',
     'safe unsafe',
     'space-between',
-))
+])
 def test_justify_self_invalid(rule):
     assert_invalid(f'justify-self: {rule}')
+
+
+@assert_no_logs
+@pytest.mark.parametrize(('rule', 'value'), [
+    ('normal', 'normal'),
+    ('light', ('light',)),
+    ('dark', ('dark',)),
+    ('light dark', ('light', 'dark')),
+    ('dark light', ('dark', 'light')),
+    ('light only', ('light', 'only')),
+    ('only light', ('light', 'only')),
+    ('dark dark', ('dark', 'dark')),
+    ('light something', ('light', 'something')),
+    ('only dark light', ('dark', 'light', 'only')),
+    ('only something light', ('something', 'light', 'only')),
+])
+def test_color_scheme(rule, value):
+    assert get_value(f'color-scheme: {rule}') == value
+
+
+@assert_no_logs
+@pytest.mark.parametrize('rule', [
+    'normal only',
+    'normal something',
+    'only',
+    'only only',
+    'light only dark',
+])
+def test_color_scheme_invalid(rule):
+    assert_invalid(f'color-scheme: {rule}')
