@@ -98,6 +98,31 @@ def test_image_svg_align_none(assert_pixels):
     ''')
 
 
+@assert_no_logs
+def test_image_svg_align_no_viewbox(assert_pixels):
+    assert_pixels('''
+        BBRRRRRR
+        BBRRRRRR
+        RRRRRRGG
+        RRRRRRGG
+        ________
+        ________
+        ________
+        ________
+    ''', '''
+      <style>
+        @page { size: 8px 8px }
+        svg { display: block; height: 4px; width: 8px }
+      </style>
+      <svg width="4px" height="4px"
+           xmlns="http://www.w3.org/2000/svg">
+        <rect width="4" height="4" fill="red" />
+        <rect width="1" height="2" fill="blue" />
+        <rect x="3" y="2" width="1" height="2" fill="lime" />
+      </svg>
+    ''')
+
+
 @assert_no_logs
 def test_image_svg_align_meet_x(assert_pixels):
     assert_pixels('''
@@ -257,6 +282,7 @@ def test_image_image(assert_pixels):
       </svg>
     ''' % path2url(resource_path('pattern.png')))
 
+
 @assert_no_logs
 def test_image_image_rendering(assert_pixels):
     assert_pixels('''
@@ -279,6 +305,7 @@ def test_image_image_rendering(assert_pixels):
       </svg>
     ''' % path2url(resource_path('pattern.png')))
 
+
 def test_image_image_wrong(assert_pixels):
     assert_pixels('''
         ____
@@ -294,3 +321,53 @@ def test_image_image_wrong(assert_pixels):
         <image xlink:href="it doesn’t exist, mouhahahaha" />
       </svg>
     ''')
+
+
+@assert_no_logs
+def test_image_in_g_height_only(assert_pixels):
+    """Test that image inside g with only height set preserves aspect ratio."""
+    assert_pixels('''
+        rrBBBBBB
+        rrBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+    ''', '''
+      <style>
+        @page { size: 8px 8px }
+        svg { display: block }
+      </style>
+      <svg width="8px" height="8px" xmlns="http://www.w3.org/2000/svg">
+        <g>
+          <image image-rendering="pixelated" href="%s" height="8px"/>
+        </g>
+      </svg>
+    ''' % path2url(resource_path('pattern.png')))
+
+
+@assert_no_logs
+def test_image_in_g_width_only(assert_pixels):
+    """Test that image inside g with only width set preserves aspect ratio."""
+    assert_pixels('''
+        rrBBBBBB
+        rrBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+        BBBBBBBB
+    ''', '''
+      <style>
+        @page { size: 8px 8px }
+        svg { display: block }
+      </style>
+      <svg width="8px" height="8px" xmlns="http://www.w3.org/2000/svg">
+        <g>
+          <image image-rendering="pixelated" href="%s" width="8px"/>
+        </g>
+      </svg>
+    ''' % path2url(resource_path('pattern.png')))
