@@ -7,11 +7,11 @@ import pytest
 from .testing_utils import FakeHTML, capture_logs, resource_path
 
 
-@pytest.mark.parametrize('url, base_url', (
+@pytest.mark.parametrize(('url', 'base_url'), [
     ('https://weasyprint.org]', resource_path('<inline HTML>')),
     ('https://weasyprint.org]', 'https://weasyprint.org]'),
     ('https://weasyprint.org/', 'https://weasyprint.org]'),
-))
+])
 def test_malformed_url_link(url, base_url):
     """Test malformed URLs."""
     with capture_logs() as logs:
