@@ -12,10 +12,10 @@ from pathlib import Path
 from urllib.parse import urljoin
 
 import cssselect2
-import html5lib
 import tinycss2
+import tinyhtml5
 
-VERSION = __version__ = '62.3'
+VERSION = __version__ = '67.0'
 
 #: Default values for command-line and Python API options. See
 #: :func:`__main__.main` to learn more about specific options for
@@ -39,12 +39,17 @@ VERSION = __version__ = '62.3'
 #:     A PDF version number.
 #: :param bool pdf_forms:
 #:     Whether PDF forms have to be included.
+#: :param bool pdf_tags:
+#:     Whether PDF should be tagged for accessibility.
 #: :param bool uncompressed_pdf:
 #:     Whether PDF content should be compressed.
 #: :param bool custom_metadata:
 #:     Whether custom HTML metadata should be stored in the generated PDF.
 #: :param bool presentational_hints:
 #:     Whether HTML presentational hints are followed.
+#: :param bool srgb:
+#:     Whether sRGB color profile should be included and set as default for
+#:     device-dependant RGB colors.
 #: :param bool optimize_images:
 #:     Whether size of embedded images should be optimized, with no quality
 #:     loss.
@@ -68,9 +73,11 @@ DEFAULT_OPTIONS = {
     'pdf_variant': None,
     'pdf_version': None,
     'pdf_forms': None,
+    'pdf_tags': False,
     'uncompressed_pdf': False,
     'custom_metadata': False,
     'presentational_hints': False,
+    'srgb': False,
     'optimize_images': False,
     'jpeg_quality': None,
     'dpi': None,
@@ -80,8 +87,8 @@ DEFAULT_OPTIONS = {
 }
 
 __all__ = [
-    'HTML', 'CSS', 'DEFAULT_OPTIONS', 'Attachment', 'Document', 'Page',
-    'default_url_fetcher', 'VERSION', '__version__']
+    'CSS', 'DEFAULT_OPTIONS', 'HTML', 'VERSION', 'Attachment', 'Document', 'Page',
+    '__version__', 'default_url_fetcher']
 
 
 # Import after setting the version, as the version is used in other modules
@@ -107,7 +114,7 @@ def _find_base_url(html_document, fallback_base_url):
 
 
 class HTML:
-    """HTML document parsed by html5lib.
+    """HTML document parsed by tinyhtml5.
 
     You can just create an instance with a positional argument:
     ``doc = HTML(something)``
@@ -165,14 +172,14 @@ class HTML:
             guess, filename, url, file_obj, string, base_url, url_fetcher)
         with result as (source_type, source, base_url, protocol_encoding):
             if isinstance(source, str):
-                result = html5lib.parse(source, namespaceHTMLElements=False)
+                result = tinyhtml5.parse(source, namespace_html_elements=False)
             else:
-                kwargs = {'namespaceHTMLElements': False}
+                kwargs = {'namespace_html_elements': False}
                 if protocol_encoding is not None:
                     kwargs['transport_encoding'] = protocol_encoding
                 if encoding is not None:
                     kwargs['override_encoding'] = encoding
-                result = html5lib.parse(source, **kwargs)
+                result = tinyhtml5.parse(source, **kwargs)
         self.base_url = _find_base_url(result, base_url)
         self.url_fetcher = url_fetcher
         self.media_type = media_type
@@ -191,7 +198,8 @@ class HTML:
     def _ph_stylesheets(self):
         return [HTML5_PH_STYLESHEET]
 
-    def render(self, font_config=None, counter_style=None, **options):
+    def render(self, font_config=None, counter_style=None, color_profiles=None,
+               **options):
         """Lay out and paginate the document, but do not (yet) export it.
 
         This returns a :class:`document.Document` object which provides
@@ -210,13 +218,16 @@ class HTML:
         :returns: A :class:`document.Document` object.
 
         """
+        for unknown in set(options) - set(DEFAULT_OPTIONS):
+            LOGGER.warning('Unknown rendering option: %s.', unknown)
         new_options = DEFAULT_OPTIONS.copy()
         new_options.update(options)
         options = new_options
-        return Document._render(self, font_config, counter_style, options)
+        return Document._render(
+            self, font_config, counter_style, color_profiles, options)
 
     def write_pdf(self, target=None, zoom=1, finisher=None,
-                  font_config=None, counter_style=None, **options):
+                  font_config=None, counter_style=None, color_profiles=None, **options):
         """Render the document to a PDF file.
 
         This is a shortcut for calling :meth:`render`, then
@@ -256,7 +267,7 @@ class HTML:
         new_options.update(options)
         options = new_options
         return (
-            self.render(font_config, counter_style, **options)
+            self.render(font_config, counter_style, color_profiles, **options)
             .write_pdf(target, zoom, finisher, **options))
 
 
@@ -279,7 +290,8 @@ class CSS:
                  string=None, encoding=None, base_url=None,
                  url_fetcher=default_url_fetcher, _check_mime_type=False,
                  media_type='print', font_config=None, counter_style=None,
-                 matcher=None, page_rules=None):
+                 color_profiles=None, matcher=None, page_rules=None, layers=None,
+                 layer=None):
         PROGRESS_LOGGER.info(
             'Step 2 - Fetching and parsing CSS - %s',
             filename or url or getattr(file_obj, 'name', 'CSS string'))
@@ -300,9 +312,13 @@ class CSS:
         self.base_url = base_url
         self.matcher = matcher or cssselect2.Matcher()
         self.page_rules = [] if page_rules is None else page_rules
+        self.layers = [] if layers is None else layers
+        counter_style = {} if counter_style is None else counter_style
+        color_profiles = {} if color_profiles is None else color_profiles
         preprocess_stylesheet(
             media_type, base_url, stylesheet, url_fetcher, self.matcher,
-            self.page_rules, font_config, counter_style)
+            self.page_rules, self.layers, font_config, counter_style, color_profiles,
+            layer=layer)
 
 
 class Attachment:
@@ -312,6 +328,9 @@ class Attachment:
     HTML specific arguments (``encoding`` and ``media_type``) are not
     supported.
 
+    :param str name:
+        The name of the attachment to be included in the PDF document.
+        May be :obj:`None`.
     :param str description:
         A description of the attachment to be included in the PDF document.
         May be :obj:`None`.
@@ -329,11 +348,12 @@ class Attachment:
     """
     def __init__(self, guess=None, filename=None, url=None, file_obj=None,
                  string=None, base_url=None, url_fetcher=default_url_fetcher,
-                 description=None, created=None, modified=None,
+                 name=None, description=None, created=None, modified=None,
                  relationship='Unspecified'):
         self.source = _select_source(
             guess, filename, url, file_obj, string, base_url=base_url,
             url_fetcher=url_fetcher)
+        self.name = name
         self.description = description
         self.relationship = relationship
         self.md5 = None
@@ -415,6 +435,7 @@ def _select_source(guess=None, filename=None, url=None, file_obj=None,
         assert string is not None
         yield 'string', string, base_url, None
 
+
 # Work around circular imports.
 from .css import preprocess_stylesheet  # noqa: I001, E402
 from .html import (  # noqa: E402
