@@ -1,10 +1,10 @@
 """Layout for pages and CSS3 margin boxes."""
 
 import copy
-from itertools import chain
+from collections import defaultdict, namedtuple
 from math import inf
 
-from ..css import PageType, computed_from_cascaded
+from ..css import AnonymousStyle
 from ..formatting_structure import boxes, build
 from ..logger import PROGRESS_LOGGER
 from .absolute import absolute_box_layout, absolute_layout
@@ -14,6 +14,8 @@ from .min_max import handle_min_max_height, handle_min_max_width
 from .percent import resolve_percentages
 from .preferred import max_content_width, min_content_width
 
+PageType = namedtuple('PageType', ['side', 'blank', 'name', 'index', 'groups'])
+
 
 class OrientedBox:
     @property
@@ -24,6 +26,12 @@ class OrientedBox:
     def outer(self):
         return self.sugar + self.inner
 
+    @outer.setter
+    def outer(self, new_outer_width):
+        self.inner = min(
+            max(self.min_content_size, new_outer_width - self.sugar),
+            self.max_content_size)
+
     @property
     def outer_min_content_size(self):
         return self.sugar + (
@@ -34,10 +42,6 @@ class OrientedBox:
         return self.sugar + (
             self.max_content_size if self.inner == 'auto' else self.inner)
 
-    def shrink_to_fit(self, available):
-        self.inner = min(
-            max(self.min_content_size, available), self.max_content_size)
-
 
 class VerticalBox(OrientedBox):
     def __init__(self, context, box):
@@ -173,7 +177,7 @@ def compute_fixed_dimension(context, box, outer, vertical, top_or_left):
     box.restore_box_attributes()
 
 
-def compute_variable_dimension(context, side_boxes, vertical, outer_sum):
+def compute_variable_dimension(context, side_boxes, vertical, available_size):
     """Compute and set a margin box fixed dimension on ``box``
 
     Described in: https://drafts.csswg.org/css-page-3/#margin-dimension
@@ -187,8 +191,8 @@ def compute_variable_dimension(context, side_boxes, vertical, outer_sum):
     :param vertical:
         ``True`` to set height, margin-top and margin-bottom;
         ``False`` for width, margin-left and margin-right.
-    :param outer_sum:
-        The target total outer dimension (max box width or height).
+    :param available_size:
+        The distance between the page box’s left right border edges
 
     """
     box_class = VerticalBox if vertical else HorizontalBox
@@ -201,68 +205,121 @@ def compute_variable_dimension(context, side_boxes, vertical, outer_sum):
         if box.margin_b == 'auto':
             box.margin_b = 0
 
-    if box_b.box.is_generated:
-        if box_b.inner == 'auto':
-            ac_max_content_size = 2 * max(
-                box_a.outer_max_content_size, box_c.outer_max_content_size)
-            if outer_sum >= (
-                    box_b.outer_max_content_size + ac_max_content_size):
-                box_b.inner = box_b.max_content_size
-            else:
-                ac_min_content_size = 2 * max(
-                    box_a.outer_min_content_size,
-                    box_c.outer_min_content_size)
-                box_b.inner = box_b.min_content_size
-                available = outer_sum - box_b.outer - ac_min_content_size
-                if available > 0:
-                    weight_ac = ac_max_content_size - ac_min_content_size
-                    weight_b = (
-                        box_b.max_content_size - box_b.min_content_size)
-                    weight_sum = weight_ac + weight_b
-                    # By definition of max_content_size and min_content_size,
-                    # weights can not be negative. weight_sum == 0 implies that
-                    # max_content_size == min_content_size for each box, in
-                    # which case the sum can not be both <= and > outer_sum
-                    # Therefore, one of the last two 'if' statements would not
-                    # have lead us here.
-                    assert weight_sum > 0
-                    box_b.inner += available * weight_b / weight_sum
-        if box_a.inner == 'auto':
-            box_a.shrink_to_fit((outer_sum - box_b.outer) / 2 - box_a.sugar)
-        if box_c.inner == 'auto':
-            box_c.shrink_to_fit((outer_sum - box_b.outer) / 2 - box_c.sugar)
-    else:
+    if not box_b.box.is_generated:
         # Non-generated boxes get zero for every box-model property
         assert box_b.inner == 0
         if box_a.inner == box_c.inner == 'auto':
-            if outer_sum >= (
+            # A and C both have 'width: auto'
+            if available_size > (
                     box_a.outer_max_content_size +
                     box_c.outer_max_content_size):
-                box_a.inner = box_a.max_content_size
-                box_c.inner = box_c.max_content_size
+                # sum of the outer max-content widths
+                # is less than the available width
+                flex_space = (
+                    available_size -
+                    box_a.outer_max_content_size -
+                    box_c.outer_max_content_size)
+                flex_factor_a = box_a.outer_max_content_size
+                flex_factor_c = box_c.outer_max_content_size
+                flex_factor_sum = flex_factor_a + flex_factor_c
+                if flex_factor_sum == 0:
+                    flex_factor_sum = 1
+                box_a.outer = box_a.max_content_size + (
+                    flex_space * flex_factor_a / flex_factor_sum)
+                box_c.outer = box_c.max_content_size + (
+                    flex_space * flex_factor_c / flex_factor_sum)
+            elif available_size > (
+                    box_a.outer_min_content_size +
+                    box_c.outer_min_content_size):
+                # sum of the outer min-content widths
+                # is less than the available width
+                flex_space = (
+                    available_size -
+                    box_a.outer_min_content_size -
+                    box_c.outer_min_content_size)
+                flex_factor_a = (
+                    box_a.max_content_size - box_a.min_content_size)
+                flex_factor_c = (
+                    box_c.max_content_size - box_c.min_content_size)
+                flex_factor_sum = flex_factor_a + flex_factor_c
+                if flex_factor_sum == 0:
+                    flex_factor_sum = 1
+                box_a.outer = box_a.min_content_size + (
+                    flex_space * flex_factor_a / flex_factor_sum)
+                box_c.outer = box_c.min_content_size + (
+                    flex_space * flex_factor_c / flex_factor_sum)
             else:
-                box_a.inner = box_a.min_content_size
-                box_c.inner = box_c.min_content_size
-                available = outer_sum - box_a.outer - box_c.outer
-                if available > 0:
-                    weight_a = (
-                        box_a.max_content_size - box_a.min_content_size)
-                    weight_c = (
-                        box_c.max_content_size - box_c.min_content_size)
-                    weight_sum = weight_a + weight_c
-                    # By definition of max_content_size and min_content_size,
-                    # weights can not be negative. weight_sum == 0 implies that
-                    # max_content_size == min_content_size for each box, in
-                    # which case the sum can not be both <= and > outer_sum
-                    # Therefore, one of the last two 'if' statements would not
-                    # have lead us here.
-                    assert weight_sum > 0
-                    box_a.inner += available * weight_a / weight_sum
-                    box_c.inner += available * weight_c / weight_sum
-        elif box_a.inner == 'auto':
-            box_a.shrink_to_fit(outer_sum - box_c.outer - box_a.sugar)
-        elif box_c.inner == 'auto':
-            box_c.shrink_to_fit(outer_sum - box_a.outer - box_c.sugar)
+                # otherwise
+                flex_space = (
+                    available_size -
+                    box_a.outer_min_content_size -
+                    box_c.outer_min_content_size)
+                flex_factor_a = box_a.min_content_size
+                flex_factor_c = box_c.min_content_size
+                flex_factor_sum = flex_factor_a + flex_factor_c
+                if flex_factor_sum == 0:
+                    flex_factor_sum = 1
+                box_a.outer = box_a.min_content_size + (
+                    flex_space * flex_factor_a / flex_factor_sum)
+                box_c.outer = box_c.min_content_size + (
+                    flex_space * flex_factor_c / flex_factor_sum)
+        else:
+            # only one box has 'width: auto'
+            if box_a.inner == 'auto':
+                box_a.outer = available_size - box_c.outer
+            elif box_c.inner == 'auto':
+                box_c.outer = available_size - box_a.outer
+    else:
+        if box_b.inner == 'auto':
+            # resolve any auto width of the middle box (B)
+            ac_max_content_size = 2 * max(
+                box_a.outer_max_content_size, box_c.outer_max_content_size)
+            if available_size > (
+                    box_b.outer_max_content_size + ac_max_content_size):
+                flex_space = (
+                    available_size -
+                    box_b.outer_max_content_size -
+                    ac_max_content_size)
+                flex_factor_b = box_b.outer_max_content_size
+                flex_factor_ac = ac_max_content_size
+                flex_factor_sum = flex_factor_b + flex_factor_ac
+                if flex_factor_sum == 0:
+                    flex_factor_sum = 1
+                box_b.outer = box_b.max_content_size + (
+                    flex_space * flex_factor_b / flex_factor_sum)
+            else:
+                ac_min_content_size = 2 * max(
+                    box_a.outer_min_content_size, box_c.outer_min_content_size)
+                if available_size > (
+                        box_b.outer_min_content_size + ac_min_content_size):
+                    flex_space = (
+                        available_size -
+                        box_b.outer_min_content_size -
+                        ac_min_content_size)
+                    flex_factor_b = (
+                        box_b.max_content_size - box_b.min_content_size)
+                    flex_factor_ac = ac_max_content_size - ac_min_content_size
+                    flex_factor_sum = flex_factor_b + flex_factor_ac
+                    if flex_factor_sum == 0:
+                        flex_factor_sum = 1
+                    box_b.outer = box_b.min_content_size + (
+                        flex_space * flex_factor_b / flex_factor_sum)
+                else:
+                    flex_space = (
+                        available_size -
+                        box_b.outer_min_content_size -
+                        ac_min_content_size)
+                    flex_factor_b = box_b.min_content_size
+                    flex_factor_ac = ac_min_content_size
+                    flex_factor_sum = flex_factor_b + flex_factor_ac
+                    if flex_factor_sum == 0:
+                        flex_factor_sum = 1
+                    box_b.outer = box_b.min_content_size + (
+                        flex_space * flex_factor_b / flex_factor_sum)
+        if box_a.inner == 'auto':
+            box_a.outer = (available_size - box_b.outer) / 2
+        if box_c.inner == 'auto':
+            box_c.outer = (available_size - box_b.outer) / 2
 
     # And, we’re done!
     assert 'auto' not in [box.inner for box in side_boxes]
@@ -320,8 +377,7 @@ def make_margin_boxes(context, page, state):
         style = context.style_for(page.page_type, at_keyword)
         if style is None:
             # doesn't affect counters
-            style = computed_from_cascaded(
-                element=None, cascaded={}, parent_style=page.style)
+            style = AnonymousStyle(page.style)
         _standardize_page_based_counters(style, at_keyword)
         box = boxes.MarginBox(at_keyword, style)
         # Empty boxes should not be generated, but they may be needed for
@@ -436,7 +492,8 @@ def margin_box_content_layout(context, page, box):
     box, resume_at, next_page, _, _, _ = block_container_layout(
         context, box, bottom_space=-inf, skip_stack=None, page_is_empty=True,
         absolute_boxes=positioned_boxes, fixed_boxes=positioned_boxes,
-        adjoining_margins=None, discard=False, max_lines=None)
+        adjoining_margins=None, first_letter_style=None, first_line_style=None,
+        discard=False, max_lines=None)
     assert resume_at is None
     for absolute_box in positioned_boxes:
         absolute_layout(
@@ -548,9 +605,8 @@ def make_page(context, root_box, page_type, resume_at, page_number,
         previous_resume_at = resume_at
         root_box = root_box.copy_with_children([])
 
-    # TODO: handle cases where the root element is something else.
-    # See https://www.w3.org/TR/CSS21/visuren.html#dis-pos-flo
-    assert isinstance(root_box, (boxes.BlockBox, boxes.FlexContainerBox))
+    # https://www.w3.org/TR/css-display-4/#root
+    assert isinstance(root_box, boxes.BlockLevelBox)
     context.create_block_formatting_context()
     context.current_page = page_number
     context.current_page_footnotes = []
@@ -566,38 +622,71 @@ def make_page(context, root_box, page_type, resume_at, page_number,
             context.reported_footnotes = reported_footnotes[i:]
             break
 
+    # Display out-of-flow boxes broken on the previous page.
+    # TODO: we shouldn’t separate broken in-flow and out-of-flow layout.
     page_is_empty = True
     adjoining_margins = []
     positioned_boxes = []  # Mixed absolute and fixed
     out_of_flow_boxes = []
+    excluded_shapes = defaultdict(list)
     broken_out_of_flow = {}
     context_out_of_flow = context.broken_out_of_flow.values()
     context.broken_out_of_flow = broken_out_of_flow
-    for box, containing_block, skip_stack in context_out_of_flow:
+    for box, containing_block, context_box, skip_stack in context_out_of_flow:
+        if context_box:
+            context.create_block_formatting_context(context_box)
         box.position_y = root_box.content_box_y()
         if box.is_floated():
             out_of_flow_box, out_of_flow_resume_at = float_layout(
                 context, box, containing_block, positioned_boxes,
                 positioned_boxes, 0, skip_stack)
+            excluded_shapes[context_box].append(out_of_flow_box)
         else:
             assert box.is_absolutely_positioned()
             out_of_flow_box, out_of_flow_resume_at = absolute_box_layout(
                 context, box, containing_block, positioned_boxes, 0,
                 skip_stack)
         out_of_flow_boxes.append(out_of_flow_box)
+        page_is_empty = False
         if out_of_flow_resume_at:
-            broken_out_of_flow[out_of_flow_box] = (
-                box, containing_block, out_of_flow_resume_at)
+            context.add_broken_out_of_flow(
+                out_of_flow_box, box, containing_block, out_of_flow_resume_at)
+        if context_box:
+            context.finish_block_formatting_context()
+
+    # Set excluded shapes from broken out-of-flow for in-flow content.
+    for context_box, shapes in excluded_shapes.items():
+        context._excluded_shapes[context_box] = shapes
+
+    # Display in-flow content.
+    initial_root_box = root_box
+    initial_resume_at = resume_at
     root_box, resume_at, next_page, _, _, _ = block_level_layout(
         context, root_box, 0, resume_at, initial_containing_block,
         page_is_empty, positioned_boxes, positioned_boxes, adjoining_margins)
-    assert root_box
+    if not root_box:
+        # In-flow page rendering didn’t progress, only out-of-flow did. Render empty box
+        # at skip_stack and force fragmentation to make the root box and its descendants
+        # cover the whole page height.
+        assert not page_is_empty
+        box = parent = initial_root_box = initial_root_box.deepcopy()
+        skip_stack = initial_resume_at
+        while skip_stack and len(skip_stack) == 1:
+            (skip, skip_stack), = skip_stack.items()
+            box, parent = box.children[skip], box
+        parent.children = []
+        parent.force_fragmentation = True
+        root_box, _, _, _, _, _ = block_level_layout(
+            context, initial_root_box, 0, initial_resume_at, initial_containing_block,
+            True, positioned_boxes, positioned_boxes, adjoining_margins)
+        resume_at = initial_resume_at
     root_box.children = out_of_flow_boxes + root_box.children
 
     footnote_area = build.create_anonymous_boxes(footnote_area.deepcopy())
     footnote_area = block_level_layout(
-        context, footnote_area, -inf, None, footnote_area.page, True,
-        positioned_boxes, positioned_boxes)[0]
+        context, footnote_area, bottom_space=-inf, skip_stack=None,
+        containing_block=footnote_area.page, page_is_empty=True,
+        absolute_boxes=positioned_boxes, fixed_boxes=positioned_boxes)[0]
     footnote_area.translate(dy=-footnote_area.margin_height())
 
     page.fixed_boxes = [
@@ -608,12 +697,9 @@ def make_page(context, root_box, page_type, resume_at, page_number,
             context, absolute_box, page, positioned_boxes, bottom_space=0,
             skip_stack=None)
 
-    context.finish_block_formatting_context(root_box)
+    context.finish_block_formatting_context()
 
     page.children = [root_box, footnote_area]
-    descendants = chain(page.descendants(), *(
-        child.descendants() if hasattr(child, 'descendants') else (child,)
-        for child in positioned_boxes))
 
     # Update page counter values
     _standardize_page_based_counters(style, None)
@@ -637,7 +723,7 @@ def make_page(context, root_box, page_type, resume_at, page_number,
         cached_anchors.extend(x_remake_state.get('anchors', []))
         cached_lookups.extend(x_remake_state.get('content_lookups', []))
 
-    for child in descendants:
+    for child in page.descendants(placeholders=True):
         # Cache target's page counters
         anchor = child.style['anchor']
         if anchor and anchor not in cached_anchors:
@@ -718,6 +804,7 @@ def make_page(context, root_box, page_type, resume_at, page_number,
 
     if page_type.blank:
         resume_at = previous_resume_at
+        next_page = page_maker[page_number - 1][1]
 
     return page, resume_at, next_page
 
@@ -744,7 +831,77 @@ def set_page_type_computed_styles(page_type, html, style_for):
                 base_url=html.base_url)
 
 
-def remake_page(index, context, root_box, html):
+def _includes_resume_at(resume_at, page_group_resume_at):
+    if not page_group_resume_at:
+        return True
+    (page_child_index, page_child_resume_at), = page_group_resume_at.items()
+    if resume_at is None or page_child_index not in resume_at:
+        return False
+    if page_child_resume_at is None:
+        return True
+    return _includes_resume_at(resume_at[page_child_index], page_child_resume_at)
+
+
+def _update_page_groups(page_groups, resume_at, next_page, root_box, blank):
+    # https://www.w3.org/TR/css-gcpm-3/#document-sequence-selectors
+
+    # Remove or increment page groups.
+    page_groups_length = len(page_groups)
+    for i, page_group in enumerate(page_groups[:]):
+        if _includes_resume_at(resume_at, page_group[2]):
+            page_group[1] += 1
+        else:
+            page_groups.pop(i - page_groups_length)
+
+    # Add page groups.
+    if not blank:
+        if (resume_at and next_page['break'] == 'any') or not next_page['page']:
+            # We don’t have a forced page break or a named page.
+            return next_page['page']
+        if page_groups and page_groups[-1][0] == next_page['page']:
+            # We’re already in an element whose page name is the next page name.
+            return next_page['page']
+
+    # Find the box that has the named page. It is a first in-flow child of the
+    # element corresponding to resume_at.
+
+    # Find element corrensponding to resume_at.
+    current_resume_at = page_group_resume_at = copy.deepcopy(resume_at) or {0: None}
+    current_element = root_box
+    while True:
+        child_index, child_resume_at = tuple(current_resume_at.items())[-1]
+        parent_element = current_element
+        current_element = current_element.children[child_index]
+        if child_resume_at is None:
+            break
+        current_resume_at = child_resume_at
+
+    if blank:
+        # Page is blank, don’t create a new page group and return parent’s page name.
+        return parent_element.style['page']
+
+    # Find the descendant with named page.
+    while True:
+        if current_element.style['page'] == next_page['page']:
+            page_groups.append([next_page['page'], 0, page_group_resume_at])
+            return next_page['page']
+        if not isinstance(current_element, boxes.ParentBox):
+            # Shouldn’t happen.
+            return next_page['page']
+        for i, child in enumerate(current_element.children):
+            if not child.is_in_normal_flow():
+                continue
+            current_resume_at[child_index] = {i: None}
+            current_resume_at = current_resume_at[child_index]
+            child_index = i
+            current_element = child
+            break
+        else:
+            # Shouldn’t happen.
+            return next_page['page']
+
+
+def remake_page(index, page_groups, context, root_box, html):
     """Return one laid out page without margin boxes.
 
     Start with the initial values from ``context.page_maker[index]``.
@@ -757,45 +914,37 @@ def remake_page(index, context, root_box, html):
 
     """
     page_maker = context.page_maker
-    (initial_resume_at, initial_next_page, right_page, initial_page_state,
-     remake_state) = page_maker[index]
+    resume_at, next_page, right_page, page_state, _ = page_maker[index]
 
     # PageType for current page, values for page_maker[index + 1].
     # Don't modify actual page_maker[index] values!
-    # TODO: should we store (and reuse) page_type in the page_maker?
-    page_state = copy.deepcopy(initial_page_state)
-    next_page_name = initial_next_page['page']
-    first = index == 0
-    if initial_next_page['break'] in ('left', 'right'):
-        next_page_side = initial_next_page['break']
-    elif initial_next_page['break'] in ('recto', 'verso'):
+    page_state = copy.deepcopy(page_state)
+    if next_page['break'] in ('left', 'right'):
+        next_page_side = next_page['break']
+    elif next_page['break'] in ('recto', 'verso'):
         direction_ltr = root_box.style['direction'] == 'ltr'
-        break_verso = initial_next_page['break'] == 'verso'
+        break_verso = next_page['break'] == 'verso'
         next_page_side = 'right' if direction_ltr ^ break_verso else 'left'
     else:
         next_page_side = None
     blank = bool(
         (next_page_side == 'left' and right_page) or
         (next_page_side == 'right' and not right_page) or
-        (context.reported_footnotes and initial_resume_at is None))
-    if blank:
-        next_page_name = ''
+        (context.reported_footnotes and resume_at is None))
     side = 'right' if right_page else 'left'
-    page_type = PageType(side, blank, first, index, name=next_page_name)
+    name = _update_page_groups(page_groups, resume_at, next_page, root_box, blank)
+    groups = tuple((name, index) for name, index, _ in page_groups)
+    page_type = PageType(side, blank, name, index, groups)
     set_page_type_computed_styles(page_type, html, context.style_for)
 
-    context.forced_break = (
-        initial_next_page['break'] != 'any' or initial_next_page['page'])
+    context.forced_break = (next_page['break'] != 'any' or next_page['page'])
     context.margin_clearance = False
 
     # make_page wants a page_number of index + 1
     page_number = index + 1
     page, resume_at, next_page = make_page(
-        context, root_box, page_type, initial_resume_at, page_number,
-        page_state)
+        context, root_box, page_type, resume_at, page_number, page_state)
     assert next_page
-    if blank:
-        next_page['page'] = initial_next_page['page']
     right_page = not right_page
 
     # Check whether we need to append or update the next page_maker item
@@ -804,9 +953,8 @@ def remake_page(index, context, root_box, html):
         page_maker_next_changed = True
     else:
         # Check whether something changed
-        # TODO: Find what we need to compare. Is resume_at enough?
-        (next_resume_at, next_next_page, next_right_page,
-         next_page_state, _) = page_maker[index + 1]
+        next_resume_at, next_next_page, next_right_page, next_page_state, _ = (
+            page_maker[index + 1])
         page_maker_next_changed = (
             next_resume_at != resume_at or
             next_next_page != next_page or
@@ -825,7 +973,6 @@ def remake_page(index, context, root_box, html):
         # If resume_at is None (last page) it must be False to prevent endless
         # loops and list index out of range (see #794).
         remake_state['content_changed'] = resume_at is not None
-        # page_state is already a deepcopy
         item = resume_at, next_page, right_page, page_state, remake_state
         if index + 1 >= len(page_maker):
             page_maker.append(item)
@@ -843,6 +990,7 @@ def make_all_pages(context, root_box, html, pages):
     """
     i = 0
     reported_footnotes = None
+    page_groups = []
     while True:
         remake_state = context.page_maker[i][-1]
         if (len(pages) == 0 or
@@ -854,7 +1002,7 @@ def make_all_pages(context, root_box, html, pages):
             remake_state['pages_wanted'] = False
             remake_state['anchors'] = []
             remake_state['content_lookups'] = []
-            page, resume_at = remake_page(i, context, root_box, html)
+            page, resume_at = remake_page(i, page_groups, context, root_box, html)
             reported_footnotes = context.reported_footnotes
             yield page
         else:
