@@ -1,15 +1,5 @@
 """PDF/A generation."""
 
-try:
-    # Available in Python 3.9+
-    from importlib.resources import files
-except ImportError:
-    # Deprecated in Python 3.11+
-    from importlib.resources import read_binary
-else:
-    def read_binary(package, resource):
-        return (files(package) / resource).read_bytes()
-
 from functools import partial
 
 import pydyf
@@ -18,22 +8,8 @@ from .metadata import add_metadata
 
 
 def pdfa(pdf, metadata, document, page_streams, attachments, compress,
-         version):
+         version, variant):
     """Set metadata for PDF/A documents."""
-    # Add ICC profile.
-    profile = pydyf.Stream(
-        [read_binary(__package__, 'sRGB2014.icc')],
-        pydyf.Dictionary({'N': 3, 'Alternate': '/DeviceRGB'}),
-        compress=compress)
-    pdf.add_object(profile)
-    pdf.catalog['OutputIntents'] = pydyf.Array([
-        pydyf.Dictionary({
-            'Type': '/OutputIntent',
-            'S': '/GTS_PDFA1',
-            'OutputConditionIdentifier': pydyf.String('sRGB IEC61966-2.1'),
-            'DestOutputProfile': profile.reference,
-        }),
-    ])
 
     # Handle attachments.
     if version == 1:
@@ -86,9 +62,48 @@ def pdfa(pdf, metadata, document, page_streams, attachments, compress,
             pdf_object['F'] = 2 ** (3 - 1)
 
     # Common PDF metadata stream.
-    add_metadata(pdf, metadata, 'a', version, 'B', compress)
+    if version == 1:
+        # Metadata compression is forbidden for version 1.
+        compress = False
+    add_metadata(pdf, metadata, 'a', version, variant, compress)
+
+    # Remove document information.
+    if version >= 4:
+        pdf.info.clear()
 
 
 VARIANTS = {
-    f'pdf/a-{i}b': (partial(pdfa, version=i), {'version': pdf_version})
-    for i, pdf_version in enumerate(('1.4', '1.7', '1.7', '2.0'), start=1)}
+    'pdf/a-1b': (
+        partial(pdfa, version=1, variant='B'),
+        {'version': '1.4', 'identifier': True, 'srgb': True}),
+    'pdf/a-2b': (
+        partial(pdfa, version=2, variant='B'),
+        {'version': '1.7', 'identifier': True, 'srgb': True}),
+    'pdf/a-3b': (
+        partial(pdfa, version=3, variant='B'),
+        {'version': '1.7', 'identifier': True, 'srgb': True}),
+    'pdf/a-2u': (
+        partial(pdfa, version=2, variant='U'),
+        {'version': '1.7', 'identifier': True, 'srgb': True}),
+    'pdf/a-3u': (
+        partial(pdfa, version=3, variant='U'),
+        {'version': '1.7', 'identifier': True, 'srgb': True}),
+    'pdf/a-4u': (
+        partial(pdfa, version=4, variant='U'),
+        {'version': '2.0', 'identifier': True, 'srgb': True}),
+    'pdf/a-1a': (
+        partial(pdfa, version=1, variant='A'),
+        {'version': '1.4', 'identifier': True, 'srgb': True, 'pdf_tags': True}),
+    'pdf/a-2a': (
+        partial(pdfa, version=2, variant='A'),
+        {'version': '1.7', 'identifier': True, 'srgb': True, 'pdf_tags': True}),
+    'pdf/a-3a': (
+        partial(pdfa, version=3, variant='A'),
+        {'version': '1.7', 'identifier': True, 'srgb': True, 'pdf_tags': True}),
+    'pdf/a-4e': (
+        partial(pdfa, version=4, variant='E'),
+        {'version': '2.0', 'identifier': True, 'srgb': True}),
+    'pdf/a-4f': (
+        partial(pdfa, version=4, variant='F'),
+        {'version': '2.0', 'identifier': True, 'srgb': True}),
+}
